
/**
 * Copyright 2012-2013 Clint Combs
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.newhart

import com.mongodb.{DBObject}
import com.mongodb.casbah.Imports._

/** Retrieval defines the methods used to search for and retrieve entries. */
trait Retrieval {

  def search(name:String, q:DBObject, s:DBObject = MongoDBObject(), n:Option[Int] = Some(100)): Seq[Entry]

  def searchIdEntryPairs(
    name:String, q:DBObject, s:DBObject = MongoDBObject(),
    n:Option[Int] = Some(100)): Seq[(ObjectId, Entry)]

  /**
   * Retrieve the last 'n' entries in collection 'name'.
   *
   * TODO: consider changing this to return Iterator[Entry]...
   * it might be more efficient for large results
   */
  def last(name:String, n:Int): Seq[Entry]
}
