
/**
 * Copyright 2012-2013 Clint Combs
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.newhart.akka

import org.newhart.Entry
import akka.actor.{Actor,ActorRef,ActorSystem,Props}
import akka.event.Logging
import org.newhart.mongodb.{NewhartMongo,MongoEntryBuilder}
import com.mongodb.casbah.Imports._

/** DeliveryActor is an actor that delivers entries. */
class DeliveryActor(implicit mongoConnection: MongoConnection) extends Actor with NewhartMongo {

  val log = Logging(context.system, this)

  def con(): MongoConnection = mongoConnection

  def receive = {
    case e: EntryMessage => {
      log.info("entry message received: " + e.toString)
      try {
        log.info("building db object...")
        val dbObj = MongoEntryBuilder.buildMongoEntryObject(e.entry)
        log.info("writing to collection...")
        mongoConnection(dbName)(e.name) += dbObj
      } catch {
        //... failing here...
        case ex:Exception => log.error("error writing entry to '" + e.name + "': " + e.entry, ex)
      }
    }
    case _ => log.info("received unknown message")
  }

  override def postStop() = {
    log.info("closing mongoConnection")
    mongoConnection.close()
  }
}
