
/**
 * Copyright 2012-2013 Clint Combs
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.newhart.example

import org.newhart._
import org.newhart.mongodb.AuditStore
import java.util.{Date => JDate}
import com.mongodb.casbah.Imports._
import scopt.immutable.OptionParser
import com.weiglewilczek.slf4s.Logging

object CreateAudit extends App with Logging {

  val defaultSize: Int = 1000000000

  val parser = new OptionParser[CreateAuditConfig]("CreateAudit", "0.4.5-SNAPSHOT") {
    def options = Seq(
      intOpt("size", "size of the capped collection in bytes") {
        (s: Int, cfg: CreateAuditConfig) => cfg.copy(size = if (s > 0) Some(s) else Some(defaultSize))
      },
      arg("hostname", "the MongoDB hostname") {
        (s: String, cfg: CreateAuditConfig) => cfg.copy(hostname = s)
      },
      arg("collection", "the collection name") {
        (s: String, cfg: CreateAuditConfig) => cfg.copy(collection = s)
      }
    )
  }

  parser.parse(args, CreateAuditConfig()) map { cfg =>
    logger.info(cfg.toString)
    run(cfg)
  } getOrElse {
    // arguments are bad, usage message will have been displayed
  }

  def run(cfg: CreateAuditConfig) = {
    implicit val con = MongoConnection(cfg.hostname)
    implicit val store = new AuditStore()

    store.createAudit(name = cfg.collection, size = cfg.size.getOrElse(defaultSize))

    con.close
  }
}

case class CreateAuditConfig(
  hostname: String = "localhost", collection: String = "example", size: Option[Int] = Some(CreateAudit.defaultSize))
