
/**
 * Copyright 2012-2013 Clint Combs
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.newhart.japi;

import java.util.Map;
import java.util.HashMap;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import com.mongodb.DBObject;

/**
 * Converters
 */
public class Converters {

    private static final Map<Class, DBObjectConverter> m = new HashMap<Class, DBObjectConverter>();

    public static <T> void add(final Class<T> clazz, final DBObjectConverter<T> conv) {
        m.put(clazz, new NoExceptionsConverterWrapper<T>(conv));
    }

    public static <T> DBObjectConverter get(final Class<T> c) {
        return m.get(c);
    }
}

/**
 * NoExceptionsConverterWrapper is a wrapper for DBObjectConverter instances stored
 * in and returned from Converters.
 *
 * @see org.newhart.japi.Converters#get(Class)
 */
class NoExceptionsConverterWrapper<T> implements DBObjectConverter<T> {

    private static final Logger logger = LoggerFactory.getLogger(NoExceptionsConverterWrapper.class);

    private final DBObjectConverter<T> converter;

    public NoExceptionsConverterWrapper(final DBObjectConverter<T> converter) {
        this.converter = converter;
    }

    public DBObject toDB(T t) {
        try {
            return converter.toDB(t);
        } catch(final Exception e) {
            logger.error("error converting to DBObject: " + t);
            return null;
        }
    }

    public T fromDB(DBObject dbObject) {
        try {
            return converter.fromDB(dbObject);
        } catch(final Exception e) {
            logger.error("error converting from DBObject: " + dbObject);
            return null;
        }
    }
}
