
/**
 * Copyright 2012-2013 Clint Combs
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.newhart.japi;

import org.newhart.*;
import scala.Some;
import scala.Option;
import scala.None;

/**
 * NewhartJava is the starting point for using the newhart Java API.  Java applications using Newhart
 * should include the following import and call the static methods of this class:
 *
 *   import org.newhart.*;
 */
public class NewhartJava {

    /**
     * Construct a Scala Option[T] from a given value.
     */
    private static final <T> scala.Option<T> option(final T value) {
        return (value != null)?new Some<T>(value):scala.Option.apply((T) null);
    }

    public static final JEntryBuilder entry() {
        return new JEntryBuilder();
    }

    public static final JEntryBuilder entryFromOriginNow(final Class originClass, final JCriticality c) {
        final JEntryBuilder builder = new JEntryBuilder();

        builder.origin(originClass.getSimpleName());
        final java.util.Date now = Entry.now();
        builder.auditTS(now);
        builder.createTS(now);
        builder.updateTS(now);
        builder.criticality(c);

        return builder;
    }

    public static final org.newhart.Error buildError(final String msg) {
        return buildError(msg, null, null);
    }

    public static final org.newhart.Error buildError(final String msg, final String code) {
        return buildError(msg, code, null);
    }

    public static final org.newhart.Error buildError(final String msg, final String code, final String stackTrace) {
        return new org.newhart.Error(option(msg), option(code), option(stackTrace));
    }

    public static final org.newhart.Error buildErrorWithException(final String msg, final String code, final Throwable t) {
        return new org.newhart.Error(option(msg), option(code), option(org.newhart.package$.MODULE$.buildStackTraceString(t)));
    }

    public static final Warning buildWarning(final String msg) {
        return buildWarning(msg, null, null);
    }

    public static final Warning buildWarning(final String msg, final String code) {
        return buildWarning(msg, code, null);
    }

    public static final Warning buildWarning(final String msg, final String code, final String stackTrace) {
        return new Warning(option(msg), option(code), option(stackTrace));
    }

    /** The Java equivalent of org.newhart.Criticality. */
    public enum JCriticality {
        minor, major, critical
    }
}
