
/**
 * Copyright 2012-2013 Clint Combs
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.newhart.mongodb

import java.util.{Date => JDate}

import com.mongodb.casbah.Imports._
import org.newhart.{Entry,Error,Warning}

object MongoEntryBuilder {

  def buildMongoEntryObject(e:Entry):MongoDBObject = {
    val builder = MongoDBObject.newBuilder

    builder += "origin" -> e.origin
    builder += "originKey" -> e.originKey
    builder += "originKeyType" -> e.originKeyType
    builder += "originHostname" -> e.originHostname
    builder += "criticality" -> e.criticality.toString
    builder += "auditTS" -> new JDate(e.auditTS.getTime)
    builder += "createTS" -> new JDate(e.createTS.getTime)
    builder += "updateTS" -> new JDate(e.updateTS.getTime)
    builder += "msg" -> e.msg
    builder += "data" -> buildData(e.data)
    builder += "errors" -> buildErrors(e.errors)
    builder += "warnings" -> buildWarnings(e.warnings)
    builder += "labels" -> buildLabels(e)

    builder.result
  }

  private def buildData(data:Map[String,Any]):MongoDBObject = {
    val builder = MongoDBObject.newBuilder

    data.map { i => builder += (i._1 -> i._2) }

    builder.result
  }

  private def buildErrorItem(e:Error):MongoDBObject = {
    val builder = MongoDBObject.newBuilder

    builder += ("msg" -> e.msg)
    e.code match { case Some(s:String) => builder += ("code" -> s); case None => }
    e.stackTrace match { case Some(s:String) => builder += ("stackTrace" -> s); case None => }

    builder.result
  }

  private def buildErrors(errors:Seq[Error]):Array[MongoDBObject] = {
    var errorList = List[MongoDBObject]()

    errors.map { e => errorList = buildErrorItem(e) :: errorList }

    errorList.reverse.toArray
  }

  private def buildWarningItem(w:Warning):MongoDBObject = {
    val builder = MongoDBObject.newBuilder

    builder += ("msg" -> w.msg)
    w.code match { case Some(s:String) => builder += ("code" -> s); case None => }
    w.stackTrace match { case Some(s:String) => builder += ("stackTrace" -> s); case None => }

    builder.result
  }

  private def buildWarnings(warnings:Seq[Warning]):Array[MongoDBObject] = {
    var warningList = List[MongoDBObject]()

    warnings.map { w => warningList = buildWarningItem(w) :: warningList }

    warningList.reverse.toArray
  }

  private def buildLabels(e:Entry):Array[String] = {
    e.labels.toArray
  }
}
