
/**
 * Copyright 2012-2013 Clint Combs
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import com.mongodb.casbah.Imports._
import java.net.InetAddress.getLocalHost

package org {
  package object newhart {

    // implicit conversions
    implicit def stringToError(s:String):Error = Error(Some(s))
    implicit def stringToWarning(s:String):Warning = Warning(Some(s))
    implicit def exceptionToError(ex:Exception):Error =
      Error(Some(ex.toString), None, Some(buildStackTraceString(ex)))
    implicit def exceptionToWarning(ex:Exception):Warning =
      Warning(Some(ex.toString), None, Some(buildStackTraceString(ex)))

    def buildStackTraceString(t:Throwable):String = {
      import java.io.{PrintWriter,StringWriter}

      val swriter = new StringWriter()
      val writer = new PrintWriter(swriter)
      t.printStackTrace(writer)
      writer.flush

      return swriter.toString
    }

    private lazy val localhost:String = getLocalHost().getHostName()

    def defaultOriginHostname() = localhost
  }
}
